@@ -48,10 +48,6 @@ sub options { (
     "git|ro"   => "git"         # git://github.com/c9s/repo.git
 ) }
 
-sub _parse_github_links {
-    my $link=shift;
-  
-}
 
 sub run {
     my $self=shift;
